FormulaError enum

Excel-compatible formula errors.

Inheritance
Available extensions

Values

divZero → const FormulaError

#DIV/0! - Division by zero

const FormulaError('#DIV/0!')
value → const FormulaError

#VALUE! - Wrong type of argument

const FormulaError('#VALUE!')
ref → const FormulaError

#REF! - Invalid cell reference

const FormulaError('#REF!')
name → const FormulaError

#NAME? - Unrecognized formula name

const FormulaError('#NAME?')
num → const FormulaError

#NUM! - Invalid numeric value

const FormulaError('#NUM!')
na → const FormulaError

#N/A - Value not available

const FormulaError('#N/A')
null_ → const FormulaError

#NULL! - Incorrect range operator

const FormulaError('#NULL!')
calc → const FormulaError

#CALC! - Calculation error

const FormulaError('#CALC!')
circular → const FormulaError

#CIRCULAR! - Circular reference detected

const FormulaError('#CIRCULAR!')

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FormulaError>
A constant List of the values in this enum, in order of their declaration.